@@ -57,7 +57,7 @@ class Request():
 
     def post(self, payload, headers, text_response=True):
         try:
-            if (self.isRetry()):
+            if 'pwbus-correlation-id' in headers:
                 data = requests.post(
                     "http://pwbus-http/pwbus/v1/retry",
                     data={},
